@@ -34,21 +34,33 @@ class ItemUrlFilter(BaseModel):
 
 
 def it_streaming(i: ItemUrlFilter):
+    print('001')
     yield write_csv_header_to_gz(i)
+    print('002')
     for int_progress, bytes1 in it_chunk(
             i.lst_url, i.target_directory, i.lst_distinct_column, i.lst_column_match, i.sort_column):
+        print('003')
         if bytes1:
+            print('004')
             yield bytes1
         else:
+            print('005')
             continue
 
 
 def write_csv_header_to_gz(i):
-    r = requests.get(i.lst_url[0])
+    print('006')
+    r = requests.get(i.lst_url[0], verify=False)
+    print('007')
     df = pl.read_csv(r.content)
+    print('008')
     bytesio_gz = BytesIO()
+    print('009')
     with gzip.open(bytesio_gz, 'wb') as f:
+        print('010')
         f.write((','.join(df.columns) + '\n').encode('utf-8'))
+        print('011')
+    print('012')
     return bytesio_gz.getvalue()
 
 
@@ -68,5 +80,5 @@ def streaming_get(md5_hex):
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20409):
+def server(host='0.0.0.0', int_port=20410):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
